## RAGAs Evaluations
- This evaluation need the data to be indexed as a prerequisite.
- use any RAG template to index the data.
- This project has multiple implementations of RAGAs

  - LlamaIndex [implemented]
  - LangChain [in progress]
  - Haystack [in progress]